/**
 * @packageDocumentation
 * @module SecurityContextProvider
 */
import React from 'react';
import { reducer } from './reducer';
/** @ignore */

const StateContext = /*#__PURE__*/React.createContext(null);
/** @ignore */

const DispatchContext = /*#__PURE__*/React.createContext(null);
/**
 * A hook to get the security state (authenticated / not authenticated).
 *
 * NOTE: Must be used inside of a [[SecurityContextProvider]].
 * @category Hooks
 */

const useSecurityState = () => {
  const context = React.useContext(StateContext);

  if (context === null) {
    throw new Error('useSecurityState must be used within an SecurityContextProvider');
  }

  return context;
};
/**
 * A hook to get the security actions (on authenticated / on not authenticated).
 *
 * NOTE: Must be used inside of a [[SecurityContextProvider]].
 * @category Hooks
 */


const useSecurityActions = () => {
  const context = React.useContext(DispatchContext);

  if (context === null) {
    throw new Error('useSecurityActions must be used within an SecurityContextProvider');
  }

  return context;
};
/**
 *  Provides a wrapper for the security state and security actions.
 *
 *  @public
 *  @category Component
 */


const SecurityContextProvider = props => {
  const initialContextState = {
    userId: undefined,
    email: undefined,
    rememberMeDetails: {
      email: undefined,
      rememberMe: undefined
    },
    isAuthenticatedUser: false,
    isLoading: true,
    isSignOut: false,
    isShowingChangePassword: false
  };
  const [state, dispatch] = React.useReducer(reducer, initialContextState); // Function will not change for children (dispatch does not need to be a dependency)

  const onUserNotAuthenticated = React.useCallback((clearRememberMe = false, overrideRememberMeEmail) => {
    dispatch({
      type: 'userNotAuthenticated',
      payload: {
        clearRememberMe: clearRememberMe,
        overrideRememberMeEmail: overrideRememberMeEmail
      }
    });
  }, []);
  const showChangePassword = React.useCallback(() => {
    dispatch({
      type: 'showChangePassword'
    });
  }, []);
  const hideChangePassword = React.useCallback(() => {
    dispatch({
      type: 'hideChangePassword'
    });
  }, []); // Function will not change for children (dispatch does not need to be a dependency)

  const onUserAuthenticated = React.useCallback(onUserAuthenticatedArgs => {
    dispatch({
      type: 'userAuthenticated',
      payload: onUserAuthenticatedArgs
    });
  }, []); // Context value will not change unless a sub function is changed

  const memoizedAuthHelper = React.useMemo(() => {
    const authHelper = {
      onUserAuthenticated,
      onUserNotAuthenticated,
      showChangePassword,
      hideChangePassword
    };
    return authHelper;
  }, [onUserAuthenticated, onUserNotAuthenticated, showChangePassword, hideChangePassword]);
  return /*#__PURE__*/React.createElement(StateContext.Provider, {
    value: state
  }, /*#__PURE__*/React.createElement(DispatchContext.Provider, {
    value: memoizedAuthHelper
  }, props.children));
};

export { SecurityContextProvider, DispatchContext as SecurityActionContext, useSecurityState, useSecurityActions };
//# sourceMappingURL=SecurityContextProvider.js.map